@@ -469,6 +469,17 @@ Bcc: </p>
         send_mail('test text email', 'email content', ['test@example.com'])
         assert 'email.is_live = False' in lh.messages['warning'][0]
 
+    def test_email_log_entry(self, mm_tracker=None):
+        lh = logging_handler('blazeweb.mail')
+        send_mail('test text email', 'email content', ['test@example.com'])
+        assert 'Email sent: "test text email" to "test@example.com"' in lh.messages['info'][0], lh.messages['info']
+
+    def test_email_log_entry(self, mm_tracker=None):
+        lh = logging_handler('blazeweb.mail')
+        to = ['test%s@example.com' % n for n in xrange(0,12)]
+        send_mail('test text email', 'email content', to)
+        assert 'Email sent: "test text email" to "test0@example.com;test1@example.com;test2@example.com;test3@example.com;test4@example.com;test5@example.com;test6@example.com;test7@example.com;test8@example.com;test9@example.com;test10@example.com;t"' in lh.messages['info'][0], lh.messages['info']
+
     @mockmail
     def test_mockmail(self, mm_tracker=None):
         send_mail('test subject', 'email content', ['test@example.com'])
@@ -502,6 +513,13 @@ Bcc: </p>
         assert email.recipients() == ['p1@example.com', 'p2@example.com']
         assert '<p><strong>email body</strong></p>' in msg.as_string()
 
+    def test_mail_programmers_wawrning(self):
+        lh = logging_handler('blazeweb.mail')
+        settings.emails.programmers = []
+
+        email = _mail_programmers('programmers email subject', 'email body')
+        assert 'mail_programmers() used but settings.emails.programmers is empty' in lh.messages['warning'][0]
+
     def test_mail_admins(self):
         settings.email.subject_prefix = '[webapp] '
         settings.emails.admins = ('a1@example.com', 'a2@example.com')
@@ -512,6 +530,14 @@ Bcc: </p>
         assert email.recipients() == ['a1@example.com', 'a2@example.com']
         assert '<p><strong>email body</strong></p>' in msg.as_string()
 
+    def test_mail_admins_wawrning(self):
+        lh = logging_handler('blazeweb.mail')
+        settings.emails.admins = []
+
+        email = _mail_admins('admins email subject', 'email body')
+        assert 'mail_admins() used but settings.emails.admins is empty' in lh.messages['warning'][0]
+
+
     def test_nofrom(self):
         settings.emails.from_default = ''
         email = EmailMessage('Subject', 'Content', to=['to@example.com'])
